@@ -1,8 +1,10 @@
 from decimal import Decimal
 from typing import List
 
+from dirty_equals import IsDict, IsOneOf
 from fastapi import FastAPI
 from fastapi.testclient import TestClient
+from fastapi.utils import match_pydantic_error_url
 from pydantic import BaseModel, condecimal
 
 app = FastAPI()
@@ -21,59 +23,115 @@ def save_item_no_body(item: List[Item]):
 client = TestClient(app)
 
 
-single_error = {
-    "detail": [
-        {
-            "ctx": {"limit_value": 0.0},
-            "loc": ["body", 0, "age"],
-            "msg": "ensure this value is greater than 0",
-            "type": "value_error.number.not_gt",
-        }
-    ]
-}
-
-multiple_errors = {
-    "detail": [
-        {
-            "loc": ["body", 0, "name"],
-            "msg": "field required",
-            "type": "value_error.missing",
-        },
-        {
-            "loc": ["body", 0, "age"],
-            "msg": "value is not a valid decimal",
-            "type": "type_error.decimal",
-        },
-        {
-            "loc": ["body", 1, "name"],
-            "msg": "field required",
-            "type": "value_error.missing",
-        },
-        {
-            "loc": ["body", 1, "age"],
-            "msg": "value is not a valid decimal",
-            "type": "type_error.decimal",
-        },
-    ]
-}
-
-
 def test_put_correct_body():
     response = client.post("/items/", json=[{"name": "Foo", "age": 5}])
     assert response.status_code == 200, response.text
-    assert response.json() == {"item": [{"name": "Foo", "age": 5}]}
+    assert response.json() == {
+        "item": [
+            {
+                "name": "Foo",
+                "age": IsOneOf(
+                    5,
+                    # TODO: remove when deprecating Pydantic v1
+                    "5",
+                ),
+            }
+        ]
+    }
 
 
 def test_jsonable_encoder_requiring_error():
     response = client.post("/items/", json=[{"name": "Foo", "age": -1.0}])
     assert response.status_code == 422, response.text
-    assert response.json() == single_error
+    assert response.json() == IsDict(
+        {
+            "detail": [
+                {
+                    "type": "greater_than",
+                    "loc": ["body", 0, "age"],
+                    "msg": "Input should be greater than 0",
+                    "input": -1.0,
+                    "ctx": {"gt": 0.0},
+                    "url": match_pydantic_error_url("greater_than"),
+                }
+            ]
+        }
+    ) | IsDict(
+        # TODO: remove when deprecating Pydantic v1
+        {
+            "detail": [
+                {
+                    "ctx": {"limit_value": 0.0},
+                    "loc": ["body", 0, "age"],
+                    "msg": "ensure this value is greater than 0",
+                    "type": "value_error.number.not_gt",
+                }
+            ]
+        }
+    )
 
 
 def test_put_incorrect_body_multiple():
     response = client.post("/items/", json=[{"age": "five"}, {"age": "six"}])
     assert response.status_code == 422, response.text
-    assert response.json() == multiple_errors
+    assert response.json() == IsDict(
+        {
+            "detail": [
+                {
+                    "type": "missing",
+                    "loc": ["body", 0, "name"],
+                    "msg": "Field required",
+                    "input": {"age": "five"},
+                    "url": match_pydantic_error_url("missing"),
+                },
+                {
+                    "type": "decimal_parsing",
+                    "loc": ["body", 0, "age"],
+                    "msg": "Input should be a valid decimal",
+                    "input": "five",
+                },
+                {
+                    "type": "missing",
+                    "loc": ["body", 1, "name"],
+                    "msg": "Field required",
+                    "input": {"age": "six"},
+                    "url": match_pydantic_error_url("missing"),
+                },
+                {
+                    "type": "decimal_parsing",
+                    "loc": ["body", 1, "age"],
+                    "msg": "Input should be a valid decimal",
+                    "input": "six",
+                },
+            ]
+        }
+    ) | IsDict(
+        # TODO: remove when deprecating Pydantic v1
+        {
+            "detail": [
+                {
+                    "loc": ["body", 0, "name"],
+                    "msg": "field required",
+                    "type": "value_error.missing",
+                },
+                {
+                    "loc": ["body", 0, "age"],
+                    "msg": "value is not a valid decimal",
+                    "type": "type_error.decimal",
+                },
+                {
+                    "loc": ["body", 1, "name"],
+                    "msg": "field required",
+                    "type": "value_error.missing",
+                },
+                {
+                    "loc": ["body", 1, "age"],
+                    "msg": "value is not a valid decimal",
+                    "type": "type_error.decimal",
+                },
+            ]
+        }
+    )
 
 
 def test_openapi_schema():
@@ -126,11 +184,23 @@ def test_openapi_schema():
                     "type": "object",
                     "properties": {
                         "name": {"title": "Name", "type": "string"},
-                        "age": {
-                            "title": "Age",
-                            "exclusiveMinimum": 0.0,
-                            "type": "number",
-                        },
+                        "age": IsDict(
+                            {
+                                "title": "Age",
+                                "anyOf": [
+                                    {"exclusiveMinimum": 0.0, "type": "number"},
+                                    {"type": "string"},
+                                ],
+                            }
+                        )
+                        | IsDict(
+                            # TODO: remove when deprecating Pydantic v1
+                            {
+                                "title": "Age",
+                                "exclusiveMinimum": 0.0,
+                                "type": "number",
+                            }
+                        ),
                     },
                 },
                 "ValidationError": {
